@@ -43,7 +43,7 @@ function ret = curvefit_stat (f, pfin, x, y, settings)
   endif
 
   if (! isempty (dfdp = optimget (settings, "dfdp")) && ...
-      ! (ismatrix (dfdp) && ! ischar (dfdp)))
+      ! isnumeric (dfdp))
     if (ischar (dfdp))
       dfdp = str2func (dfdp);
     endif
