@@ -167,7 +167,7 @@ function Df = jacobs (x, f, hook)
         for id = act_idx.'
 
           res = __bw_prcv__ (child_data(id, 1));
-          if (ismatrix (res))
+          if (isnumeric (res))
             error ("child closed pipe without sending");
           endif
           res = res.psend_var;
