@@ -45,21 +45,23 @@
 ##
 ## @item stol
 ## Scalar tolerance on fractional improvement in scalar sum of squares, i.e.,
-## @code{sum ((@var{wt} .* (@var{y}-@var{f}))^2)}.  Defaults to 0.0001;
+## @code{sum ((@var{wt} .* (@var{y}-@var{f}))^2)}.  Set to 0.0001 if
+## empty or not given;
 ##
 ## @item niter
-## Maximum number of iterations. Default to 20.
+## Maximum number of iterations.  Set to 20 if empty or not given.
 ##
 ## @item wt
 ## Statistical weights (same dimensions as @var{y}).  These should be
 ## set to be proportional to @code{sqrt (@var{y}) ^-1}, i.e., the
 ## covariance matrix of the data is assumed to be proportional to
 ## diagonal with diagonal equal to @code{(@var{wt}.^2)^-1}.  The constant of
-## proportionality will be estimated.  Defaults to @code{ones (size (@var{y}))}.
+## proportionality will be estimated.  Set to @code{ones (size
+## (@var{y}))} if empty or not given.
 ##
 ## @item dp
-## Fractional increment of @var{p} for numerical partial derivatives. Defaults
-## to @code{0.001 * ones (size (@var{pin}))}.
+## Fractional increment of @var{p} for numerical partial derivatives.  Set
+## to @code{0.001 * ones (size (@var{pin}))} if empty or not given.
 ##
 ## @itemize @bullet
 ## @item dp(j) > 0 means central differences on j-th parameter p(j).
@@ -68,11 +70,11 @@
 ## @end itemize
 ##
 ## @item dFdp
-## Name of partial derivative function in quotes or function
-## handle. Default is @code{dfdp}, a slow but general partial derivatives
-## function. The function must be of the form
-## @code{prt = dfdp (x, f, p, dp, F [,bounds])}.  For backwards compatibility,
-## the function will only be called with an extra 'bounds' argument if the
+## Name of partial derivative function in quotes or function handle. If
+## not given or empty, set to @code{dfdp}, a slow but general partial
+## derivatives function. The function must be of the form @code{prt =
+## dfdp (x, f, p, dp, F [,bounds])}.  For backwards compatibility, the
+## function will only be called with an extra 'bounds' argument if the
 ## 'bounds' option is explicitly specified to leasqr (see dfdp.m).
 ##
 ## @item options
@@ -298,7 +300,11 @@ function [f,p,cvg,iter,corp,covp,covr,stdresid,Z,r2]= ...
   ## argument processing
   ##
 
-  if (nargin > 8)
+  if (nargin < 4)
+    print_usage ();
+  endif
+
+  if (nargin > 8 && ! isempty (dFdp))
     if (ischar (dFdp))
       dfdp = str2func (dFdp);
     else
@@ -306,10 +312,10 @@ function [f,p,cvg,iter,corp,covp,covr,stdresid,Z,r2]= ...
     endif
   endif
   
-  if (nargin <= 7) dp=.001*(pin*0+1); endif #DT
-  if (nargin <= 6) wt = ones (size (y)); endif	# SMB modification
+  if (nargin <= 7 || isempty (dp)) dp=.001*(pin*0+1); endif #DT
+  if (nargin <= 6 || isempty (wt)) wt = ones (size (y)); endif #SMB modification
   if (nargin <= 5) niter = []; endif
-  if (nargin == 4) stol=.0001; endif
+  if (nargin == 4 || isempty (stol)) stol=.0001; endif
   if (ischar (F)) F = str2func (F); endif
   ##
 
@@ -349,7 +355,7 @@ function [f,p,cvg,iter,corp,covp,covr,stdresid,Z,r2]= ...
 				# constraints, later converted to
 				# logical index
   if (nargin > 9)
-    if (ismatrix (options)) # backwards compatibility
+    if (isnumeric (options)) # backwards compatibility
       tp = options;
       options = struct ("fract_prec", tp(:, 1));
       if (columns (tp) > 1)
@@ -380,7 +386,7 @@ function [f,p,cvg,iter,corp,covp,covr,stdresid,Z,r2]= ...
     endif
     if (isfield (options, "inequc"))
       inequc = options.inequc;
-      if (ismatrix (inequc{1}))
+      if (isnumeric (inequc{1}))
 	mc = inequc{1};
 	vc = inequc{2};
 	if (length (inequc) > 2)
@@ -397,7 +403,7 @@ function [f,p,cvg,iter,corp,covp,covr,stdresid,Z,r2]= ...
 	have_gencstr = true;
 	f_gencstr = inequc{1};
 	if (length (inequc) > 1)
-	  if (ismatrix (inequc{2}))
+	  if (isnumeric (inequc{2}))
 	    lid = 2;
 	    df_gencstr = @ dcdp;
 	  else
@@ -446,7 +452,7 @@ function [f,p,cvg,iter,corp,covp,covr,stdresid,Z,r2]= ...
     endif
     if (isfield (options, "equc"))
       equc = options.equc;
-      if (ismatrix (equc{1}))
+      if (isnumeric (equc{1}))
 	emc = equc{1};
 	evc = equc{2};
 	if (length (equc) > 2)
@@ -463,7 +469,7 @@ function [f,p,cvg,iter,corp,covp,covr,stdresid,Z,r2]= ...
 	have_genecstr = true;
 	f_genecstr = equc{1};
 	if (length (equc) > 1)
-	  if (ismatrix (equc{2}))
+	  if (isnumeric (equc{2}))
 	    lid = 2;
 	    df_genecstr = @ dcdp;
 	  else
