@@ -110,6 +110,17 @@
 
 function [x,v,nev,varargout] = minimize (f,args,varargin)
 
+  ## Reasons for deprecation have been outlined in
+  ##
+  ## http://lists.gnu.org/archive/html/octave-maintainers/2014-06/msg00130.html
+  ##
+  persistent warned = false;
+  if (! warned)
+    warned = true;
+    warning ("Octave:deprecated-function",
+             "The frontend `minimize' has been deprecated, and will be removed in the future. An alternative frontend is `nonlin_min'. The backends `nelder_mead_min' and `bfgsmin' of `minimize' can also be called directly. The backend `d2_min' is also deprecated and its algorithm is now available as a backend to `nonlin_min'.");
+  endif
+
 ## Oldies
 ##
 ## 'df' , df      : Name of a function that returns the derivatives of f
@@ -156,8 +167,8 @@ if nargin == 3			# Accomodation to struct and list optional
 else
   opls = varargin;
 end
-ops = read_options (opls,...
-		    "op0",op0, "op1",op1, "default",default);
+ops = __read_options__ (opls, ...
+		        "op0", op0, "op1", op1, "default", default);
 
 backend=ops.backend; verbose=ops.verbose; 
 df=ops.df; d2f=ops.d2f; d2i=ops.d2i; 
