@@ -1,4 +1,4 @@
-## Copyright (C) 2010-2013 Olaf Till <i7tiol@t-online.de>
+## Copyright (C) 2010-2014 Olaf Till <i7tiol@t-online.de>
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -19,7 +19,7 @@
 ## Frontend for nonlinear fitting of values, computed by a model
 ## function, to observed values.
 ##
-## Please refer to the description of @code{nonlin_residmin}. The only
+## Please refer to the description of @code{nonlin_residmin}. The
 ## differences to @code{nonlin_residmin} are the additional arguments
 ## @var{x} (independent values, mostly, but not necessarily, an array of
 ## the same dimensions or the same number of rows as @var{y}) and
@@ -27,9 +27,18 @@
 ## guess for observed values) instead of @var{resid}, that the model
 ## function has a second obligatory argument which will be set to
 ## @var{x} and is supposed to return guesses for the observations (with
-## the same dimensions), and that the possibly user-supplied function for the
-## jacobian of the model function has also a second obligatory argument
-## which will be set to @var{x}.
+## the same dimensions), and that the possibly user-supplied function
+## for the jacobian of the model function has also a second obligatory
+## argument which will be set to @var{x}.
+##
+## @c The following block will be cut out in the package info file.
+## @c BEGIN_CUT_TEXINFO
+##
+## Also, if the setting @code{user_interaction} is given, additional
+## information is passed to these functions. Type @code{optim_doc
+## ("Common optimization options")} for this setting.
+##
+## @c END_CUT_TEXINFO
 ##
 ## @seealso {nonlin_residmin}
 ## @end deftypefn
@@ -49,11 +58,6 @@ function [p, fy, cvg, outp] = nonlin_curvefit (f, pin, x, y, settings)
     settings = struct ();
   endif
 
-  if (compare_versions (version (), "3.3.55", "<"))
-    ## optimset mechanism was fixed for option names with underscores
-    ## sometime in 3.3.54+, if I remember right
-    optimget = @ __optimget__;
-  endif
   if (! isempty (dfdp = optimget (settings, "dfdp")))
     if (ischar (dfdp))
       dfdp = str2func (dfdp);
@@ -63,6 +67,19 @@ function [p, fy, cvg, outp] = nonlin_curvefit (f, pin, x, y, settings)
     settings.dfdp =  @ (p, varargin) dfdp (p, x, varargin{:});
   endif
 
+  if (! isempty (uia = optimget (settings, "user_interaction", {})))
+    if (! iscell (uia))
+      uia = {uia};
+    endif
+    uia = cellfun (@ (f_handle) @ (p, v, s) ...
+                   f_handle (p, cell2fields ({x, y},
+                                             {"model_x", "observations"},
+                                             2, v),
+                             s),
+                   uia(:), "UniformOutput", false);
+    settings.user_interaction = uia;
+  endif
+
   [p, fy, cvg, outp] = __nonlin_residmin__ ...
       (@ (p) f (p, x), pin, settings, struct ("observations", y));
 
@@ -70,18 +87,6 @@ function [p, fy, cvg, outp] = nonlin_curvefit (f, pin, x, y, settings)
 
 endfunction
 
-function ret = __optimget__ (s, name, default)
-
-  if (isfield (s, name))
-    ret = s.(name);
-  elseif (nargin > 2)
-    ret = default;
-  else
-    ret = [];
-  endif
-
-endfunction
-
 %!demo
 %!  ## Example for linear inequality constraints
 %!  ## (see also the same example in 'demo nonlin_residmin')
