@@ -998,7 +998,9 @@ function ret = optim_problems ()
     else
       vhaveeventfunction = false;
     end
-    if (~isempty (vodeoptions.Mass) && ismatrix (vodeoptions.Mass))
+    if (~isempty (vodeoptions.Mass) && ...
+        isnumeric (vodeoptions.Mass) && ...
+        numel (size (vodeoptions.Mass)) < 3)
       vhavemasshandle = false;
       vmass = vodeoptions.Mass;
     elseif (isa (vodeoptions.Mass, 'function_handle'))
