@@ -258,7 +258,7 @@ function prt = __dfdp__ (p, func, hook)
         for id = act_idx.'
 
           res = __bw_prcv__ (child_data(id, 1));
-          if (ismatrix (res))
+          if (isnumeric (res))
             error ("child closed pipe without sending");
           endif
           res = res.psend_var;
