@@ -67,6 +67,7 @@ function [p, resid, cvg, outp] = __lm_svd__ (F, pin, hook)
   wt = hook.weights;
   fixed = hook.fixed;
   verbose = strcmp (hook.Display, "iter");
+  user_interaction = hook.user_interaction;
 
   ## only preliminary, for testing
   if (isfield (hook, "testing"))
@@ -151,6 +152,17 @@ function [p, resid, cvg, outp] = __lm_svd__ (F, pin, hook)
   gc_idx = cat (1, false (n_lcstr, 1), true (n_gencstr, 1)); # gen. constr.
   lc_idx = ~gc_idx;
 
+  if (([stop, outp.user_interaction] = ...
+       __do_user_interaction__ (user_interaction, p,
+                                struct ("iteration", 0,
+                                        "residual", f),
+                                "init")))
+    outp.niter = 0;
+    resid = f;
+    cvg = -1;
+    return;
+  endif
+
   ## do iterations
   ##
   for iter = 1:niter
@@ -450,6 +462,8 @@ function [p, resid, cvg, outp] = __lm_svd__ (F, pin, hook)
           error ("weighted residuals are not real");
         endif
         ss = r.' * r;
+        deb_printf (testing, "tried parameters:\n");
+        deb_printf (testing, "%.16e\n", p); 
         deb_printf (testing, "sbest: %.16e\n", sbest);
         deb_printf (testing, "sgoal: %.16e\n", sgoal);
         deb_printf (testing, "   ss: %.16e\n", ss);
@@ -469,8 +483,18 @@ function [p, resid, cvg, outp] = __lm_svd__ (F, pin, hook)
     endfor
     ## printf ("epsL no.: %i\n", jjj); # for testing
     epsLlast = epsL;
-    if (verbose)
-      hook.plot_cmd (f);
+
+    hook.plot_cmd (f);
+
+    if (([stop, outp.user_interaction] = ...
+         __do_user_interaction__ (user_interaction, p,
+                                  struct ("iteration", iter,
+                                          "residual", f),
+                                  "iter")))
+      outp.niter = iter;
+      resid = f;
+      cvg = -1;
+      return;
     endif
     if (skipped)
       cvg = 2;
@@ -504,6 +528,14 @@ function [p, resid, cvg, outp] = __lm_svd__ (F, pin, hook)
   resid = fbest;
   outp.niter = iter;
 
+  if (([stop, outp.user_interaction] = ...
+       __do_user_interaction__ (user_interaction, pbest,
+                                struct ("iteration", iter,
+                                        "residual", fbest),
+                                "done")))
+    cvg = -1;
+  endif
+
 endfunction
 
 function deb_printf (do_printf, varargin)
