@@ -1,4 +1,4 @@
-## Copyright (C) 2010-2013 Olaf Till <i7tiol@t-online.de>
+## Copyright (C) 2010-2014 Olaf Till <i7tiol@t-online.de>
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -20,23 +20,9 @@
 ## returned values of unchanged model function can be checked against
 ## each other exactly one time.
 
-## disabled PKG_ADD: __all_opts__ ("__nonlin_residmin__");
-
 function [p, resid, cvg, outp] = ...
       __nonlin_residmin__ (f, pin, settings, hook)
 
-  if (compare_versions (version (), "3.3.55", "<"))
-    ## optimset mechanism was fixed for option names with underscores
-    ## sometime in 3.3.54+, if I remember right
-    optimget = @ __optimget__;
-  endif
-
-  if (compare_versions (version (), "3.2.4", "<="))
-    ## For bug #31484; but Octave 3.6... shows bug #36288 due to this
-    ## workaround. Octave 3.7... seems to be all right.
-    __dfdp__ = @ __dfdp__;
-  endif
-
   ## some scalar defaults; some defaults are backend specific, so
   ## lacking elements in respective constructed vectors will be set to
   ## NA here in the frontend
@@ -81,7 +67,9 @@ function [p, resid, cvg, outp] = ...
                   "parallel_local", false, ... # Matlabs UseParallel
                                 # works differently
 		  "plot_cmd", @ (f) 0, ...
+                  "user_interaction", {}, ...
 		  "debug", false, ...
+                  "FunValCheck", "off", ...
 		  "lm_svd_feasible_alt_s", false);
     return;
   endif
@@ -132,6 +120,10 @@ function [p, resid, cvg, outp] = ...
   do_cstep_inequc = ...
       optimget (settings, "complex_step_derivative_inequc", false);
   do_cstep_equc = optimget (settings, "complex_step_derivative_equc", false);
+  if (! iscell (user_interaction = ...
+                optimget (settings, "user_interaction", {})))
+    user_interaction = {user_interaction};
+  endif
 
   any_vector_conf = ! (isempty (lbound) && isempty (ubound) && ...
 		       isempty (max_fract_change) && ...
@@ -479,13 +471,19 @@ function [p, resid, cvg, outp] = ...
 	  f (cell2struct (num2cell (p), pord, 1), varargin{:});
     endif
   endif
-  f_pin = f (pin);
+  f_pin = f (pin); # Doing this in the frontend is useful for
+                                # residual-based minimization (but not
+                                # fro scalar objective functions)
   if (isfield (hook, "observations"))
     if (any (size (f_pin) != size (obs = hook.observations)))
       error ("dimensions of observations and values of model function must match");
     endif
-    f = @ (p) f (p) - obs;
+    f = @ (varargin) f (varargin{:}) - obs;
     f_pin -= obs;
+    user_interaction = ...
+        cellfun (@ (f_handle) @ (p, v, s) ...
+                 f_handle (p, setfield (v, "model_y", v.residual + obs), s),
+                 user_interaction(:), "UniformOutput", false);
   endif
 
   ## jacobian of model function
@@ -728,15 +726,22 @@ function [p, resid, cvg, outp] = ...
   endif
 
   #### collect remaining settings
-  parallel_local = optimget (settings, "parallel_local", false);
+  parallel_local = hook.parallel_local = ...
+      __optimget_parallel_local__ (settings, false);
   hook.MaxIter = optimget (settings, "MaxIter");
   if (ischar (hook.cpiv = optimget (settings, "cpiv", @ cpiv_bard)))
     hook.cpiv = str2func (hook.cpiv);
   endif
   hook.Display = optimget (settings, "Display", "off");
-  hook.plot_cmd = optimget (settings, "plot_cmd", @ (f) 0);
+  if (isempty (plot_cmd = optimget (settings, "plot_cmd", [])))
+    hook.plot_cmd = @ (f) 0;
+  else
+    warning ("setting 'plot_cmd' is deprecated, please use 'user_interaction'");
+    hook.plot_cmd = plot_cmd;
+  endif
   hook.testing = optimget (settings, "debug", false);
   hook.new_s = optimget (settings, "lm_svd_feasible_alt_s", false);
+  hook.FunValCheck = optimget (settings, "FunValCheck", "off");
   backend = optimget (settings, "Algorithm", "lm_svd_feasible");
   backend = map_matlab_algorithm_names (backend);
   backend = map_backend (backend);
@@ -986,6 +991,7 @@ function [p, resid, cvg, outp] = ...
   ## hook.MaxIter = ; # set before
   hook.weights = weights;
   hook.fixed = fixed;
+  hook.user_interaction = user_interaction;
 
   #### call backend
 
@@ -1041,18 +1047,6 @@ function lval = assign (lval, lidx, rval)
 
 endfunction
 
-function ret = __optimget__ (s, name, default)
-
-  if (isfield (s, name))
-    ret = s.(name);
-  elseif (nargin > 2)
-    ret = default;
-  else
-    ret = [];
-  endif
-
-endfunction
-
 function ret = apply_idx_if_given  (ret, varargin)
 
   if (nargin > 1)
