@@ -177,8 +177,7 @@ function ret = __residmin_stat__ (f, pfin, settings, hook)
       error ("number of initial parameters not correct");
     endif
   endif
-  if (ismatrix (dfdp) && ! ischar (dfdp) && ! isempty (dfdp) && ...
-      np == 0)
+  if (isnumeric (dfdp) && ! isempty (dfdp) && np == 0)
     np = columns (dfdp);
   endif
 
@@ -342,8 +341,9 @@ function ret = __residmin_stat__ (f, pfin, settings, hook)
       endif
     endif
   elseif (! isa (dfdp, "function_handle"))
-    if (ismatrix (dfdp))
-      if (any (size (dfdp) != [prod(size(residuals)), np]))
+    if (isnumeric (dfdp))
+      if (numel (size_dfdp = size (dfdp)) > 2 || ...
+          any (size_dfdp != [prod(size(residuals)), np]))
 	error ("jacobian has wrong size");
       endif
     elseif (! dfdp_pstruct)
