@@ -13,9 +13,6 @@
 ## You should have received a copy of the GNU General Public License
 ## along with this program; If not, see <http://www.gnu.org/licenses/>.
 
-## The simulated annealing code is translated and adapted from siman.c,
-## written by Mark Galassi, of the GNU Scientific Library.
-
 function [p_res, objf, cvg, outp] = __sqp__ (f, pin, hook)
 
   n = length (pin);
