@@ -105,7 +105,7 @@ ans =\n\
 
 	// copy cell contents over to octave_value_list to use feval()
 	k = f_args_cell.length();
-	f_args(k); // resize only once
+	f_args(k - 1); // resize only once
 	for (i = 0; i<k; i++) f_args(i) = f_args_cell(i);
 
 	// check which arg w.r.t which we need to differentiate
